@@ -388,14 +388,14 @@ class Setup(object):
         )
         return sms
 
-    def panel_login(self, panel_serial, user_code):
-        """ Establish a connection between the alarm panel and the API server. """
-        return self.__api.panel_login(panel_serial, user_code)
-
     def panel_add(self, alias, panel_serial, master_user_code, access_proof=None):
         """ Add a new alarm panel to the user account. A master user code is required. """
         return self.__api.panel_add(alias, panel_serial, access_proof, master_user_code)
 
+    def panel_login(self, panel_serial, user_code):
+        """ Establish a connection between the alarm panel and the API server. """
+        return self.__api.panel_login(panel_serial, user_code)
+
     def panel_rename(self, alias, panel_serial):
         """ Rename an alarm panel. """
         return self.__api.panel_rename(alias, panel_serial)
@@ -412,9 +412,9 @@ class Setup(object):
         """ Complete the password reset by entering the reset code received in the email and a new password. """
         return self.__api.password_reset_complete(reset_password_code, new_password)['user_token']
 
-    def set_name_user(self, id, name):
+    def set_name_user(self, user_id, name):
         """ Set the name of a user by user ID. """
-        return self.__api.set_name('USER', id, name)['process_token']
+        return self.__api.set_name('USER', user_id, name)['process_token']
 
     def set_rest_version(self, version='latest'):
         """ 
@@ -431,3 +431,7 @@ class Setup(object):
         else:
             raise UnsupportedRestAPIVersionError(f'Rest API version {version} is not supported by server.')
 
+    def set_user_code(self, user_id, user_code):
+        """ Set the code of a user by user ID. """
+        return self.__api.set_user_code(user_code, user_id)['process_token']
+
